.. _murano-pl:

.. toctree::
   :maxdepth: 2

==================
MuranoPL Reference
==================

To develop applications, murano project refers to Murano Programming
Language (MuranoPL). It is represented by easily readable YAML and
YAQL languages. The sections below describe these languages.

.. include:: murano_pl/yaml.rst
.. include:: murano_pl/yaql.rst
.. include:: murano_pl/class_templ.rst
.. include:: murano_pl/core_classes.rst
.. include:: murano_pl/actions.rst